@@ -3,7 +3,7 @@
  */
 
 /* 
- * Copyright (C) 1986, 1988, 1989, 1991-2013 the Free Software Foundation, Inc.
+ * Copyright (C) 1986, 1988, 1989, 1991-2014 the Free Software Foundation, Inc.
  * 
  * This file is part of GAWK, the GNU implementation of the
  * AWK Programming Language.
@@ -113,12 +113,14 @@ null_array(NODE *symbol)
 	symbol->table_size = symbol->array_size = 0;
 	symbol->array_capacity = 0;
 	symbol->flags = 0;
+
 	assert(symbol->xarray == NULL);
+
 	/* vname, parent_array not (re)initialized */
 }
 
 
-/* null_lookup: assign type to an empty array. */
+/* null_lookup --- assign type to an empty array. */
 
 static NODE **
 null_lookup(NODE *symbol, NODE *subs)
@@ -340,6 +342,7 @@ force_array(NODE *symbol, bool canfatal)
 
 	switch (symbol->type) {
 	case Node_var_new:
+		symbol->xarray = NULL;	/* make sure union is as it should be */
 		null_array(symbol);
 		symbol->parent_array = NULL;	/* main array has no parent */
 		/* fall through */
@@ -845,6 +848,8 @@ asort_actual(int nargs, sort_context_t ctxt)
  		/* source array is empty */
  		if (dest != NULL && dest != array)
  			assoc_clear(dest);
+		if (list != NULL)
+			efree(list);
  		return make_number((AWKNUM) 0);
  	}
 
@@ -1274,7 +1279,7 @@ assoc_list(NODE *symbol, const char *sort_str, sort_context_t sort_ctxt)
 	INSTRUCTION *code = NULL;
 	extern int currule;
 	int save_rule = 0;
-	assoc_kind_t assoc_kind = 0;
+	assoc_kind_t assoc_kind = ANONE;
 	
 	elem_size = 1;
 
